View source: R/aft_logml_post.R
| aft.logml.post | R Documentation |
Uses bridge sampling to estimate the logarithm of the marginal likelihood of an AFT model under the normal/half-normal prior.
aft.logml.post(post.samples, bridge.args = NULL)
post.samples |
output from |
bridge.args |
a |
The function returns a list with the following objects
"aft_post"
the estimated logarithm of the marginal likelihood
an object of class bridge or bridge_list containing the output from using bridgesampling::bridge_sampler()
to compute the logarithm of the marginal likelihood of the AFT model under the normal/half-normal prior
Gronau, Q. F., Singmann, H., and Wagenmakers, E.-J. (2020). bridgesampling: An r package for estimating normalizing constants. Journal of Statistical Software, 92(10).
if (instantiate::stan_cmdstan_exists()) {
if(requireNamespace("survival")){
library(survival)
data(E1690)
## take subset for speed purposes
E1690 = E1690[1:100, ]
## replace 0 failure times with 0.50 days
E1690$failtime[E1690$failtime == 0] = 0.50/365.25
E1690$cage = as.numeric(scale(E1690$age))
data_list = list(currdata = E1690)
d.post = aft.post(
formula = survival::Surv(failtime, failcens) ~ treatment + sex + cage + node_bin,
data.list = data_list,
dist = "weibull",
beta.sd = 10,
chains = 1, iter_warmup = 500, iter_sampling = 1000
)
aft.logml.post(
post.samples = d.post,
bridge.args = list(silent = TRUE)
)
}
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.