| aft.post | R Documentation |
Sample from the posterior distribution of an accelerated failure time (AFT) model using a normal/half-normal prior.
aft.post(
formula,
data.list,
dist = "weibull",
beta.mean = NULL,
beta.sd = NULL,
scale.mean = NULL,
scale.sd = NULL,
get.loglik = FALSE,
iter_warmup = 1000,
iter_sampling = 1000,
chains = 4,
...
)
formula |
a two-sided formula giving the relationship between the response variable and covariates.
The response is a survival object as returned by the |
data.list |
a list consisting of one |
dist |
a character indicating the distribution of survival times. Currently, |
beta.mean |
a scalar or a vector whose dimension is equal to the number of regression coefficients giving
the mean parameters for the initial prior on regression coefficients. If a scalar is provided,
|
beta.sd |
a scalar or a vector whose dimension is equal to the number of regression coefficients giving
the sd parameters for the initial prior on regression coefficients. If a scalar is provided,
same as for |
scale.mean |
location parameter for the half-normal prior on the scale parameter of the AFT model. Defaults to 0. |
scale.sd |
scale parameter for the half-normal prior on the scale parameter of the AFT model. Defaults to 10. |
get.loglik |
whether to generate log-likelihood matrix. Defaults to FALSE. |
iter_warmup |
number of warmup iterations to run per chain. Defaults to 1000. See the argument |
iter_sampling |
number of post-warmup iterations to run per chain. Defaults to 1000. See the argument |
chains |
number of Markov chains to run. Defaults to 4. See the argument |
... |
arguments passed to |
The priors on the regression coefficients are independent normal distributions. When the normal priors are elicited with large variances, the prior is also referred to as the reference or vague prior. The scale parameter is assumed to be independent of the regression coefficients with a half-normal prior.
The function returns an object of class draws_df containing posterior samples. The object has two attributes:
a list of variables specified in the data block of the Stan program
a character string indicating the model name
if (instantiate::stan_cmdstan_exists()) {
if(requireNamespace("survival")){
library(survival)
data(E1690)
## take subset for speed purposes
E1690 = E1690[1:100, ]
## replace 0 failure times with 0.50 days
E1690$failtime[E1690$failtime == 0] = 0.50/365.25
E1690$cage = as.numeric(scale(E1690$age))
data_list = list(currdata = E1690)
aft.post(
formula = survival::Surv(failtime, failcens) ~ treatment + sex + cage + node_bin,
data.list = data_list,
dist = "weibull",
beta.sd = 10,
chains = 1, iter_warmup = 500, iter_sampling = 1000
)
}
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.