- formula
a two-sided formula giving the relationship between the response variable and covariates.
The response is a survival object as returned by the survival::Surv(time, event) function,
where event is a binary indicator for event (0 = no event, 1 = event has occurred). The type of
censoring is assumed to be right-censoring.
- data.list
a list of data.frames. The first element in the list is the current data, and the rest
are the historical data sets. For fitting accelerated failure time (AFT) models, all historical
data sets will be stacked into one historical data set.
- dist
a character indicating the distribution of survival times. Currently, dist can be one of the
following values: "weibull", "lognormal", or "loglogistic". Defaults to "weibull".
- beta0.mean
a scalar or a vector whose dimension is equal to the number of regression coefficients
giving the mean parameters for the prior on the historical data regression coefficients. If a
scalar is provided, beta0.mean will be a vector of repeated elements of the given scalar.
Defaults to a vector of 0s.
- beta0.sd
a scalar or a vector whose dimension is equal to the number of regression coefficients giving
the sd parameters for the prior on the historical data regression coefficients. If a scalar is
provided, same as for beta0.mean. Defaults to a vector of 10s.
- p.spike
a scalar between 0 and 1 giving the probability of the spike component in spike-and-slab prior
on commensurability parameter \(\tau\). Defaults to 0.1.
- spike.mean
a scalar giving the location parameter for the half-normal prior (spike component) on \(\tau\).
Defaults to 200.
- spike.sd
a scalar giving the scale parameter for the half-normal prior (spike component) on \(\tau\).
Defaults to 0.1.
- slab.mean
a scalar giving the location parameter for the half-normal prior (slab component) on \(\tau\).
Defaults to 0.
- slab.sd
a scalar giving the scale parameter for the half-normal prior (slab component) on \(\tau\).
Defaults to 5.
- scale.mean
location parameter for the half-normal prior on the scale parameters of current and historical
data models. Defaults to 0.
- scale.sd
scale parameter for the half-normal prior on the scale parameters of current and historical data
models. Defaults to 10.
- get.loglik
whether to generate log-likelihood matrix. Defaults to FALSE.
- iter_warmup
number of warmup iterations to run per chain. Defaults to 1000. See the argument iter_warmup in
sample() method in cmdstanr package.
- iter_sampling
number of post-warmup iterations to run per chain. Defaults to 1000. See the argument iter_sampling
in sample() method in cmdstanr package.
- chains
number of Markov chains to run. Defaults to 4. See the argument chains in sample() method in
cmdstanr package.
- ...
arguments passed to sample() method in cmdstanr package (e.g., seed, refresh, init).