- formula
a two-sided formula giving the relationship between the response variable and covariates.
The response is a survival object as returned by the survival::Surv(time, event) function,
where event is a binary indicator for event (0 = no event, 1 = event has occurred). The type of
censoring is assumed to be right-censoring.
- histdata
a data.frame giving the historical data.
- a0
a scalar between 0 and 1 giving the (fixed) power prior parameter for the historical data.
- dist
a character indicating the distribution of survival times. Currently, dist can be one of the
following values: "weibull", "lognormal", or "loglogistic". Defaults to "weibull".
- beta.mean
a scalar or a vector whose dimension is equal to the number of regression coefficients giving
the mean parameters for the initial prior on regression coefficients. If a scalar is provided,
beta.mean will be a vector of repeated elements of the given scalar. Defaults to a vector of 0s.
- beta.sd
a scalar or a vector whose dimension is equal to the number of regression coefficients giving
the sd parameters for the initial prior on regression coefficients. If a scalar is provided,
same as for beta.mean. Defaults to a vector of 10s.
- scale.mean
location parameter for the half-normal prior on the scale parameter of the AFT model. Defaults to 0.
- scale.sd
scale parameter for the half-normal prior on the scale parameter of the AFT model. Defaults to 10.
- bridge.args
a list giving arguments (other than samples, log_posterior, data, lb, and ub) to
pass onto bridgesampling::bridge_sampler().
- iter_warmup
number of warmup iterations to run per chain. Defaults to 1000. See the argument iter_warmup
in sample() method in cmdstanr package.
- iter_sampling
number of post-warmup iterations to run per chain. Defaults to 1000. See the argument iter_sampling
in sample() method in cmdstanr package.
- chains
number of Markov chains to run. Defaults to 4. See the argument chains in sample() method
in cmdstanr package.
- ...
arguments passed to sample() method in cmdstanr package (e.g., seed, refresh, init).