- formula
a two-sided formula giving the relationship between the response variable and covariates.
The response is a survival object as returned by the survival::Surv(time, event) function,
where event is a binary indicator for event (0 = no event, 1 = event has occurred). The type of
censoring is assumed to be right-censoring.
- data.list
a list of data.frames. The first element in the list is the current data, and the rest
are the historical data sets. For fitting accelerated failure time (AFT) models, all historical
data sets will be stacked into one historical data set.
- strata.list
a list of vectors specifying the stratum ID for each observation in the corresponding data set
in data.list. The first element in the list corresponds to the current data, and the rest
correspond to the historical data sets. Each vector should have the same length as the number
of rows in the respective data set in data.list, with values representing stratum labels
as positive integers (e.g., 1, 2, 3, ...).
- a0.strata
A scalar or a vector of fixed power prior parameters (\(a_0\)'s) for each stratum, with values
between 0 and 1. If a scalar is provided, it will be replicated for all strata. If a vector is
provided, its length must match the total number of unique strata across all data sets. The first
element of a0.strata corresponds to stratum 1, the second to stratum 2, and so on.
- dist
a character indicating the distribution of survival times. Currently, dist can be one of the
following values: "weibull", "lognormal", or "loglogistic". Defaults to "weibull".
- beta.mean
a scalar or a vector whose dimension is equal to the number of regression coefficients giving
the mean parameters for the initial prior on regression coefficients. If a scalar is provided,
beta.mean will be a vector of repeated elements of the given scalar. Defaults to a vector of 0s.
- beta.sd
a scalar or a vector whose dimension is equal to the number of regression coefficients giving
the sd parameters for the initial prior on regression coefficients. If a scalar is provided,
same as for beta.mean. Defaults to a vector of 10s.
- scale.mean
location parameter for the half-normal prior on the scale parameter of the AFT model. Defaults to 0.
- scale.sd
scale parameter for the half-normal prior on the scale parameter of the AFT model. Defaults to 10.
- get.loglik
whether to generate log-likelihood matrix. Defaults to FALSE.
- iter_warmup
number of warmup iterations to run per chain. Defaults to 1000. See the argument iter_warmup in
sample() method in cmdstanr package.
- iter_sampling
number of post-warmup iterations to run per chain. Defaults to 1000. See the argument iter_sampling
in sample() method in cmdstanr package.
- chains
number of Markov chains to run. Defaults to 4. See the argument chains in sample() method in
cmdstanr package.
- ...
arguments passed to sample() method in cmdstanr package (e.g., seed, refresh, init).