- formula
a two-sided formula giving the relationship between the response variable and covariates.
The response is a survival object as returned by the survival::Surv(time, event) function,
where event is a binary indicator for event (0 = no event, 1 = event has occurred). The type of
censoring is assumed to be right-censoring.
- data.list
a list of data.frames. The first element in the list is the current data, and the rest
are the historical data sets. For fitting piecewise exponential (PWE) models, all historical
data sets will be stacked into one historical data set.
- breaks
a numeric vector specifying the time points that define the boundaries of the piecewise
intervals. The values should be in ascending order, with the final value being greater than
or equal to the maximum observed time.
- meta.mean.mean
a scalar or a vector whose dimension is equal to the number of regression coefficients giving
the means for the normal hyperpriors on the mean hyperparameters of regression coefficients.
If a scalar is provided, meta.mean.mean will be a vector of repeated elements of the given
scalar. Defaults to a vector of 0s.
- meta.mean.sd
a scalar or a vector whose dimension is equal to the number of regression coefficients giving
the sds for the normal hyperpriors on the mean hyperparameters of regression coefficients. If
a scalar is provided, same as for meta.mean.mean. Defaults to a vector of 10s.
- meta.sd.mean
a scalar or a vector whose dimension is equal to the number of regression coefficients giving
the means for the half-normal hyperpriors on the sd hyperparameters of regression coefficients.
If a scalar is provided, same as for meta.mean.mean. Defaults to a vector of 0s.
- meta.sd.sd
a scalar or a vector whose dimension is equal to the number of regression coefficients giving
the sds for the half-normal hyperpriors on the sd hyperparameters of regression coefficients.
If a scalar is provided, same as for meta.mean.mean. Defaults to a vector of 1s.
- base.hazard.mean
a scalar or a vector whose dimension is equal to the number of intervals giving the location
parameters for the half-normal priors on the baseline hazards of the PWE model. If a scalar is
provided, same as for meta.mean.mean. Defaults to 0.
- base.hazard.sd
a scalar or a vector whose dimension is equal to the number of intervals giving the scale
parameters for the half-normal priors on the baseline hazards of the PWE model. If a scalar is
provided, same as for meta.mean.mean. Defaults to 10.
- get.loglik
whether to generate log-likelihood matrix. Defaults to FALSE.
- iter_warmup
number of warmup iterations to run per chain. Defaults to 1000. See the argument iter_warmup in
sample() method in cmdstanr package.
- iter_sampling
number of post-warmup iterations to run per chain. Defaults to 1000. See the argument iter_sampling
in sample() method in cmdstanr package.
- chains
number of Markov chains to run. Defaults to 4. See the argument chains in sample() method in
cmdstanr package.
- ...
arguments passed to sample() method in cmdstanr package (e.g., seed, refresh, init).